@@ -72,7 +72,7 @@ class Domoticz(IPlugin):
 		else:
 			bodies = "pas de local_search_query"
 #
-		idex= location + " " + local
+		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
 			log.msg("ids  :  %s" % (rs['ids']))
